import axios from 'axios'
import qs from 'qs'
import { Message } from 'element-ui'
// import md5 from 'blueimp-md5'

const httpRequest = axios.create({
  // baseURL: process.env.VUE_APP_BASE_API,
  timeout: 60000,
  withCredentials: true
})

// 请求拦截
httpRequest.interceptors.request.use(
  function(config) {
    const defaultParams = {
      timestamp: parseInt(Date.now() / 1000),
      nonce: Math.random()
        .toString(36)
        .slice(-8)
    }
    // 接口请求参数
    let params = config.params || config.data
    // 排序
    function alphabeticalSort(a, b) {
      return a.localeCompare(b)
    }
    // https://gitlab.ezijing.com/root/api-documents/-/blob/master/messages/api/%E7%8E%AF%E5%A2%83%E8%AF%B4%E6%98%8E.md#%E6%8E%A5%E5%8F%A3%E7%AD%BE%E5%90%8D
    params = Object.assign({}, defaultParams, params)
    const str = qs.stringify(Object.assign({}, params, { salt: 'n7xAav2tSjn9Ysnr' }), { sort: alphabeticalSort })
    const strs = qs.parse(str)
    Object.keys(strs).map(item => {
      strs[item] = Array.isArray(strs[item]) ? JSON.stringify(strs[item]) : strs[item]
    })
    params.signature = 'UG7wBenexQhiuD2wpCwuxkU0jqcj006d'
    if (config.method === 'post') {
      config.data = params
    } else {
      config.params = params
    }
    // config.data = params
    // if (config.headers['Content-Type'] === 'multipart/form-data') {
    //   const form = new window.FormData()
    //   for (const key in config.data) {
    //     form.append(key, config.data[key])
    //   }
    //   config.data = form
    // }
    return config
  },
  function(error) {
    return Promise.reject(error)
  }
)

// 响应拦截
httpRequest.interceptors.response.use(
  function(response) {
    const { data } = response
    if (data.msg) {
      if (data.msg === '请先登录') {
        window.location.href = `${webConf.others.loginUrl}?rd=${encodeURIComponent(window.location.href)}`
      }
    }
    if (parseInt(data.code) === 1) {
      return Message.error(data.msg)
    }
    if (data.code) {
      if (data.code === 4001) {
        window.location.href = `${webConf.others.loginUrl}?rd=${encodeURIComponent(window.location.href)}`
      }
      return data.message ? Message.error(data.message) : Message.error(data.msg)
    }
    return data
  },
  function(error) {
    if (error.response) {
      const { status, message } = error.response.data
      // 未登录
      if (status === 403) {
        window.location.href = `${webConf.others.loginUrl}?rd=${encodeURIComponent(window.location.href)}`
      }
      Message.error(message || error.response.data)
      return Promise.reject(error.response)
    } else {
      Message.error(error)
    }
    return Promise.reject(error)
  }
)

export default httpRequest
